import { Component, OnInit } from '@angular/core';
import {environment} from '../../../../environments/environment';
import {FormBuilder, FormGroup, Validators} from '_@angular_forms@9.0.7@@angular/forms';
import {DiscountService} from '../../../services/discount.service';
import {CouponService} from '../../../services/coupon.service';
import {IconService} from '../../../services/icon.service';
import {NzMessageService} from '_ng-zorro-antd@9.3.0@ng-zorro-antd';
import {Router} from '_@angular_router@9.0.7@@angular/router';
import {CommonsService} from '../../../services/commons.service';
import {RechargeService} from '../../../services/recharge.service';

@Component({
  selector: 'app-price-list',
  templateUrl: './price-list.component.html',
  styleUrls: ['./price-list.component.scss']
})
export class PriceListComponent implements OnInit {
  WEB_SERVE_URL = environment.imageUrl;
  searchForm: FormGroup; // 搜索框
  validateForm: FormGroup; // 添加框
  requestData = []; // 列表数据

  total: number; // 页码
  pageNum = 1; // 页码
  pageSize = 10; // 条码
  loading = true;
  isVisible = false;
  id: number;

  constructor(
      private form: FormBuilder,
      private recharge: RechargeService,
      private discount: DiscountService,
      private coupon: CouponService,
      private iconService: IconService,
      private message: NzMessageService,
      private router: Router,
      private common: CommonsService
  ) {
  }

  ngOnInit(): void {
    this.init();
  }

  public init(): void {
    this.searchForm = this.form.group({
      type: [null],
    });
    this.validateForm = this.form.group({
      type: [null, [Validators.required]],
      price: [null, [Validators.required]],
      realPrice: [null, [Validators.required]],
    });

    this.getRequest(true, this.searchForm.value);
  }

  // 查询列表
  public getRequest(reset: boolean = false, whereObject: object) {

    this.loading = false;
    if (reset) {
      this.pageNum = 1;
    }
    whereObject['pageNum'] = this.pageNum;
    whereObject['pageSize'] = this.pageSize;
    this.recharge.getListOutRechargePrice(whereObject, data => {
      if (data['return_code'] === '000000') {
        this.requestData = data['return_data'].list;
        this.total = data['return_data'].total;
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  // 重置
  public resetForm(): void {
    this.searchForm.reset();
  }

  // 修改
  public getEdit(id?: number): void {
    this.isVisible  = true;
  }

  // 查看详情
  public getDetail(id: number): void {
    this.router.navigate(['/admin/company/company-detail'], {
      queryParams: {
        companyId: id
      }
    }).then(r => console.log(r));
  }



  handleOk(): void {
    // tslint:disable-next-line:forin
    for (const i in this.validateForm.controls) {
      this.validateForm.controls[i].markAsDirty();
      this.validateForm.controls[i].updateValueAndValidity();
      if (this.validateForm.controls[i].errors != null) {
        this.message.error('必填项不能为空');
        return;
      }
    }
    this.validateForm.value['agentId'] = this.id;
    this.recharge.insertPrice(this.validateForm.value , data => {
      if (data['return_code'] === '000000') {
        this.message.success('添加成功');
        this.isVisible = false;
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  handleCancel(): void {
    this.isVisible = false;
  }

}
